Simple content management system for Django 1.8+
================================================

``django-pages-cms`` is a simple content management system for Django 1.8+

.. image:: https://travis-ci.org/dlancer/django-pages-cms.svg?branch=master
    :target: https://travis-ci.org/dlancer/django-pages-cms/
    :alt: Build status

.. image:: https://img.shields.io/pypi/v/django-pages-cms.svg
    :target: https://pypi.python.org/pypi/django-pages-cms/
    :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/dm/django-pages-cms.svg
    :target: https://pypi.python.org/pypi/django-pages-cms/
    :alt: Number of PyPI downloads

.. image:: https://img.shields.io/pypi/format/django-pages-cms.svg
    :target: https://pypi.python.org/pypi/django-pages-cms/
    :alt: Download format

.. image:: https://img.shields.io/pypi/l/django-pages-cms.svg
    :target: https://pypi.python.org/pypi/django-pages-cms/
    :alt: License

Requirements
------------

::

    Django>=1.8
    django-appcore>=0.0.9
    django-mptt>=0.8.4
    django-guardian>=1.4.4
    django-markitup>=2.3.1
    python-slugify>=1.2.0
    PyYAML>=3.11
    Markdown>=2.6.6


Usage
=====

You may find detailed documentation in the "docs" directory.

